import { promises as fs } from 'fs'
import { pascalCase } from 'pascal-case'
import { promisify } from 'util'
import _rimraf from 'rimraf'
import mkdirp from 'mkdirp'
const rimraf = promisify(_rimraf)

const DIR_NAME = __dirname+'/..'
const DIR = 'dist'

const base = `import Vue from 'vue';
import { ExtendedVue } from 'vue/types/vue';
export interface BootstrapIconProps {
  size: string;
}

export type VueBootstrapIcon = ExtendedVue<
  Vue,
  {},
  {},
  {},
  BootstrapIconProps
  >;
`
const dtsTemplate = (name: string) => `  export const ${name}: VueBootstrapIcon;`

async function run() {
  const svgFileNames = await fs.readdir('./node_modules/bootstrap-icons/icons')
  const dist =
    base +
    svgFileNames.map((fileName) => {
      const kebabName = `${fileName.split('.svg')[0]}-icon`
      const pascalName = pascalCase(kebabName)
      return dtsTemplate(pascalName)
    }).join('\n')
  await Promise.all(['', '.cjs', '.es'].map(async(suffix)=>{
    await fs.writeFile(DIR_NAME+'/'+DIR+'/vue-bootstrap-icons'+suffix+'.d.ts', dist, { encoding: 'utf8'})
  }))
}

run()
